@@ -1,6 +1,7 @@
 OC.L10N.register(
     "contacts",
     {
+    "Import contacts" : "連絡先のインポート",
     "Details" : "詳細",
     "All contacts" : "すべての連絡先",
     "Contacts" : "連絡先",
@@ -12,13 +13,11 @@ OC.L10N.register(
     "There was an error fetching the member list" : "メンバーリストの取得中にエラーが発生しました",
     "Please select a team" : "チームを選択してください",
     "Loading team…" : "チームを読み込み中...",
-    "Loading contacts …" : "連絡先を読み込み中...",
     "There are no contacts yet" : "連絡先はまだありません",
     "Create contact" : "連絡先を作成",
     "There are no contacts in this group" : "このグループには連絡先がありません",
     "Create contacts" : "連絡先を作成",
     "Add contacts" : "連絡先を追加",
-    "Loading …" : "読み込み中…",
     "Manage team" : "チームを管理",
     "Leave team" : "チームを離脱",
     "Delete team" : "チームを削除",
@@ -41,6 +40,7 @@ OC.L10N.register(
     "An error occurred while creating the group" : "グループ作成中にエラーが発生しました",
     "This team already exists" : "このチームはすでに存在しています",
     "An error happened during the creation of the team" : "チームの作成中にエラーが発生しました",
+    "Recently contacted" : "最近連絡した",
     "Contact groups" : "連絡先グループ",
     "Create a new contact group" : "新規連絡先グループを作成",
     "Contact group name" : "連絡先グループ名",
@@ -58,7 +58,6 @@ OC.L10N.register(
     "Unshare {addressbook}?" : "{addressbook}の共有を解除しますか?",
     "Deletion of address book was not successful." : "アドレス帳の削除に失敗しました。",
     "Renaming of address book was not successful." : "アドレス帳の名前変更に失敗しました。",
-    "{addressbookname} (Disabled)" : "{addressbookname} (無効)",
     "Download" : "ダウンロード",
     "Show" : "表示",
     "Unshare from me" : "共有を自分から解除",
@@ -71,7 +70,6 @@ OC.L10N.register(
     "Unable to change permissions" : "権限を変更できません。",
     "can edit" : "編集を許可",
     "Choose a vCard file to import" : "インポートするvCardファイルを選択",
-    "Import contacts" : "連絡先のインポート",
     "Import into the {addressbookName} address book" : "アドレス帳 {addressbookName} にインポートします",
     "Select local file" : "ローカルファイルの選択",
     "Import from files" : "ファイルからインポート ",
@@ -88,17 +86,14 @@ OC.L10N.register(
     "Sort by {sorting}" : "{sorting} で整列",
     "Manages" : "管理",
     "Oversees" : "統括",
+    "An error happened during the config change" : "構成の変更中にエラーが発生しました",
     "Enforce password protection on files shared to this team" : "このチームと共有するファイルにパスワード保護を強制します",
     "Use a unique password for all shares to this team" : "このチームのすべての共有に一意のパスワードを使用します",
-    "Unique password …" : "固有パスワード...",
     "Save" : "保存",
     "Change unique password" : "固有パスワードを変更",
     "Failed to save password. Please try again later." : "パスワードを保存できませんでした。後でもう一度やり直してください",
-    "An error happened during the config change" : "構成の変更中にエラーが発生しました",
     "There is no description for this team" : "このチームの説明はありません",
     "Enter a description for the team" : "チームの説明を入力します",
-    "An error happened during description sync" : "説明の同期中にエラーが発生しました",
-    "An error happened during name sync" : "名前の同期中にエラーが発生しました",
     "Team name" : "チーム名",
     "Edit" : "編集",
     "Cancel" : "キャンセル",
@@ -153,10 +148,12 @@ OC.L10N.register(
     "Calendar events with you" : "カレンダーイベント",
     "Deck cards with you" : "デッキカード",
     "No shared items with this contact" : "この連絡先との共有アイテムはありません",
-    "Search contacts …" : "連絡先を検索...",
+    "Groups" : "グループ",
     "Add to {group}" : "{group}に追加",
+    "Add members to {group}" : "ユーザーを{group}に追加",
     "Remove {type}" : "{type} を削除",
     "Add to group" : "グループに追加",
+    "Add members to group" : "ユーザーをグループに追加",
     "Search {types}" : "{types} を検索",
     "Search for people to add" : "追加するメンバーを検索",
     "No results" : "該当なし",
@@ -167,14 +164,6 @@ OC.L10N.register(
     "Local team" : "ローカルチーム",
     "This team will not be shared with the other instances of the global scale" : "このチームはグローバルスケールの他のインスタンスと共有されません",
     "Create team" : "チームを作成する",
-    "Unable to get the results" : "結果を取得できません",
-    "Some members could not be added" : "一部のメンバーを追加できませんでした",
-    "There was an issue adding members to the team" : "チームへのメンバーの追加で問題が発生しました",
-    "Loading members list …" : "メンバーリストを読み込んでいます…",
-    "The list of members is only visible to members of this team" : "メンバーのリストは、このチームのメンバーにのみ表示されます",
-    "You currently have no access to the member list" : "メンバーリストへのアクセス権がありません",
-    "Add to {circle}" : "{circle} に追加",
-    "Pending" : "保留中",
     "Promote as sole owner" : "唯一の所有者に昇格",
     "Promote to {level}" : "{level}に昇格",
     "Demote to {level}" : "{level}に降格",
@@ -185,7 +174,12 @@ OC.L10N.register(
     "Reject membership request" : "メンバーシップリクエストを拒否",
     "Manage level" : "レベルを管理",
     "Remove member" : "メンバーを削除",
-    "Select chart …" : "組織図を選択...",
+    "Unable to get the results" : "結果を取得できません",
+    "Some members could not be added" : "一部のメンバーを追加できませんでした",
+    "There was an issue adding members to the team" : "チームへのメンバーの追加で問題が発生しました",
+    "The list of members is only visible to members of this team" : "メンバーのリストは、このチームのメンバーにのみ表示されます",
+    "You currently have no access to the member list" : "メンバーリストへのアクセス権がありません",
+    "Pending" : "保留中",
     "Chart" : "チャート",
     "Select Date" : "日付を選択",
     "Select type" : "タイプを選択",
@@ -194,6 +188,7 @@ OC.L10N.register(
     "Select option" : "オプションを選択",
     "Personal dates" : "個人的な日程",
     "Add property of this type" : "このタイプのプロパティーを追加",
+    "Member" : "メンバー",
     "Unable to create the contact." : "連絡先を追加できません。",
     "Contact not found" : "連絡先がありません",
     "Group {group} not found" : "グループ {group} が見つかりません",
@@ -221,7 +216,6 @@ OC.L10N.register(
     "Link copied to the clipboard" : "クリップボードにリンクをコピーしました",
     "Could not copy link to the clipboard." : "クリップボードにコピーできませんでした",
     "Not grouped" : "グループ化されていません",
-    "Recently contacted" : "最近連絡した",
     "Organization chart" : "組織図",
     "Teams are groups of people that you can create yourself and with whom you can share data. They can be made up of other accounts or groups of accounts of the Nextcloud instance, but also of contacts from your address book or even external people by simply entering their e-mail addresses." : "チームは、自分で作成し、データを共有できるユーザーのグループです。Nextcloudインスタンスの他のアカウントやアカウントのグループだけでなく、アドレス帳の連絡先や、電子メールアドレスを入力するだけの外部のユーザーで構成することもできます。",
     "Team" : "チーム",
@@ -229,7 +223,6 @@ OC.L10N.register(
     "Group" : "グループ",
     "Email" : "メール",
     "Contact" : "連絡先",
-    "Member" : "メンバー",
     "Moderator" : "モデレータ",
     "Admin" : "管理者",
     "Owner" : "所有者",
@@ -243,7 +236,6 @@ OC.L10N.register(
     "users" : "ユーザー",
     "Users" : "ユーザー",
     "groups" : "グループ",
-    "Groups" : "グループ",
     "teams" : "チーム",
     "email addresses" : "メールアドレス",
     "Email addresses" : "メールアドレス",
@@ -313,17 +305,13 @@ OC.L10N.register(
     "Unable to create team {circleName}" : "チーム{circleName}を作成できません",
     "Unable to delete team {circleId}" : "チーム {circleId} を削除できません",
     "Unable to delete contact" : "連絡先を削除できません。",
-    "Password protection" : "パスワード保護",
-    "Team owned by {owner}" : "{owner}が所有するチーム",
-    "Team settings" : "チーム設定",
-    "Description" : "詳細",
-    "Team resources" : "チームのリソース",
-    "Anything shared with this team will show up here" : "このチームと共有されているものはすべてここに表示されます",
-    "Settings" : "Settings",
-    "Actions" : "アクション",
-    "Team members" : "チームのメンバー",
-    "Add members" : "メンバーの追加",
-    "Visibility" : "公開レベル",
-    "Team membership" : "チームのメンバー"
+    "Loading contacts …" : "連絡先を読み込み中...",
+    "Loading …" : "読み込み中…",
+    "{addressbookname} (Disabled)" : "{addressbookname} (無効)",
+    "Unique password …" : "固有パスワード...",
+    "Search contacts …" : "連絡先を検索...",
+    "Loading members list …" : "メンバーリストを読み込んでいます…",
+    "Add to {circle}" : "{circle} に追加",
+    "Select chart …" : "組織図を選択..."
 },
 "nplurals=1; plural=0;");
